==> owncloud-app-documents-1%3A0.10.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/documents/l10n/ar.php <==
<?php
$TRANSLATIONS = array(
"Documents" => "وثائق",
"You don't have permission to rename this document" => "لا تمتلك الصلاحية لاعادة تسمية هذا المستند",
"Saved" => "حفظ",
"Saving..." => "جاري الحفظ...",
"Failed to load documents." => "فشل في تحميل الوثائق",
"No connection to server. Trying to reconnect." => "لا يوجد اتصال مع الخادم. في محاولة لإعادة الاتصال.",
"Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead." => "ترك هذه الصفحة في وضع التعديل ممكن ان يسبب فقد للبيانات. ننصح باستخدام زر اغلاق",
"Failed to load this document. Please check if it can be opened with an external odt editor. This might also mean it has been unshared or deleted recently." => "فشل في تحميل المستند. يرجى التحقق من امكانية فتحة عن طريق محرر odt خارجي. قد يعني انه تم الغاء المشاركة او حذفة مؤخرا",
"Save" => "حفظ",
"Loading documents..." => "يتم تحميل المستند ...",
"'.' is an invalid file name." => "\".\" اسم ملف غير صحيح.",
"File name cannot be empty." => "اسم الملف لا يجوز أن يكون فارغا",
"Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." => "اسم غير صحيح , الرموز  '\\', '/', '<', '>', ':', '\"', '|', '?' و \"*\" غير مسموح استخدامها",
"Align Left" => "محاذاة إلى اليسار",
"Alignment" => "المحاذاة",
"Align Right" => "محاذاة إلى اليمين",
"Annotate" => "تعليق",
"Background" => "خلفية",
"Bold" => "عريض",
"Bottom" => "أسفل",
"Cancel" => "الغاء",
"Center" => "وسط",
"Clone" => "استنساخ ",
"Clone this Style" => "استنساخ هذا الشكل",
"Close" => "إغلاق",
"Color" => "اللون",
"Create" => "انشئ",
"Decrease Indent" => "تقليص المسافة الابتدائية",
"Default Style" => "الشكل الافتراضي",
"Delete" => "إلغاء",
"Family" => "العائلة",
"Font" => "الخط",
"Font Effects" => "تاثيرات الخط",
"Format" => "الشكل",
"Increase Indent" => "توسيع المسافة الابتدائية",
"Insert Image" => "إدراج صورة",
"Invite Members" => "دعوة الأعضاء",
"Italic" => "مائل",
"Justified" => "مضبوط",
"Justify" => "برر",
"Left" => "اليسار",
"Loading" => "تحميل",
"Members" => "الأعضاء",
"New Name:" => "اسم جديد:",
"OK" => "تم",
"Open" => "افتح",
"Options" => "خيارات",
"Paragraph..." => "فقرة...",
"Paragraph Styles" => "شكل الفقرة ",
"Redo" => "إعادة",
"Right" => "اليمين",
"Size" => "حجم",
"Spacing" => "المسافة",
"Strikethrough" => "مشطوب",
"Style" => "شكل",
"Text" => "معلومات إضافية",
"Top" => "أعلى",
"Underline" => "مسطّر",
"Undo" => "تراجع",
"Unknown Author" => "المؤلف مجهول",
"Edit" => "تعديل",
"Share" => "شارك",
"Disabled" => "معطلة",
"New document" => "مستند جديد",
"Upload" => "رفع",
"Save new documents to" => "حفظ المستندات الجديدة إلى",
"Wrong password. Please retry." => "كلمة مرور خاطئة. يرجى إعادة المحاولة",
"Password" => "كلمة المرور",
"This link has been expired or is never existed. Please contact the person who shared it with you for details." => "هذا الرابط قد انتهى او لم ينشئ. يرجى الاتصال بالشخص المعني للمزيد من المعلومات.",
"Advanced feature-set" => "طقم الأدوات المتقدم",
"(Unstable)" => "(غير مستقر)"
);
$PLURAL_FORMS = "nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;";

==> owncloud-app-documents-1%3A9.0.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/documents/l10n/ar.php <==
<?php
$TRANSLATIONS = array(
"Documents" => "وثائق",
"You don't have permission to rename this document" => "لا تمتلك الصلاحية لاعادة تسمية هذا المستند",
"Saved" => "حفظ",
"Saving..." => "جاري الحفظ...",
"Failed to load documents." => "فشل في تحميل الوثائق",
"No connection to server. Trying to reconnect." => "لا يوجد اتصال مع الخادم. في محاولة لإعادة الاتصال.",
"Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead." => "ترك هذه الصفحة في وضع التعديل ممكن ان يسبب فقد للبيانات. ننصح باستخدام زر اغلاق",
"Failed to load this document. Please check if it can be opened with an external odt editor. This might also mean it has been unshared or deleted recently." => "فشل في تحميل المستند. يرجى التحقق من امكانية فتحة عن طريق محرر odt خارجي. قد يعني انه تم الغاء المشاركة او حذفة مؤخرا",
"Save" => "حفظ",
"Loading documents..." => "يتم تحميل المستند ...",
"'.' is an invalid file name." => "\".\" اسم ملف غير صحيح.",
"File name cannot be empty." => "اسم الملف لا يجوز أن يكون فارغا",
"Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." => "اسم غير صحيح , الرموز  '\\', '/', '<', '>', ':', '\"', '|', '?' و \"*\" غير مسموح استخدامها",
"Align Left" => "محاذاة إلى اليسار",
"Alignment" => "المحاذاة",
"Align Right" => "محاذاة إلى اليمين",
"Annotate" => "تعليق",
"Background" => "خلفية",
"Bold" => "عريض",
"Bottom" => "أسفل",
"Cancel" => "الغاء",
"Center" => "وسط",
"Clone" => "استنساخ ",
"Clone this Style" => "استنساخ هذا الشكل",
"Close" => "إغلاق",
"Color" => "اللون",
"Create" => "انشئ",
"Decrease Indent" => "تقليص المسافة الابتدائية",
"Default Style" => "الشكل الافتراضي",
"Delete" => "إلغاء",
"Family" => "العائلة",
"Font" => "الخط",
"Font Effects" => "تاثيرات الخط",
"Format" => "الشكل",
"Increase Indent" => "توسيع المسافة الابتدائية",
"Insert Image" => "إدراج صورة",
"Invite Members" => "دعوة الأعضاء",
"Italic" => "مائل",
"Justified" => "مضبوط",
"Justify" => "برر",
"Left" => "اليسار",
"Loading" => "تحميل",
"Members" => "الأعضاء",
"New Name:" => "اسم جديد:",
"OK" => "تم",
"Open" => "افتح",
"Options" => "خيارات",
"Paragraph..." => "فقرة...",
"Paragraph Styles" => "شكل الفقرة ",
"Redo" => "إعادة",
"Right" => "اليمين",
"Size" => "حجم",
"Spacing" => "المسافة",
"Strikethrough" => "مشطوب",
"Style" => "شكل",
"Text" => "معلومات إضافية",
"Top" => "أعلى",
"Underline" => "مسطّر",
"Undo" => "تراجع",
"Unknown Author" => "المؤلف مجهول",
"Shared" => "مشارك",
"Error" => "خطأ",
"Error while sharing" => "حصل خطأ عند عملية المشاركة",
"Error while unsharing" => "حصل خطأ عند عملية إزالة المشاركة",
"Error while changing permissions" => "حصل خطأ عند عملية إعادة تعيين التصريح بالتوصل",
"Shared with you and the group {group} by {owner}" => "شورك معك ومع المجموعة {group} من قبل {owner}",
"Shared with you by {owner}" => "شورك معك من قبل {owner}",
"Share with users or groups …" => "شارِك مع مستخدمين أو مجموعات",
"Share with users, groups or remote users …" => "شارِك مع مستخدمين أو مجموعات أو مستخدمين عن بُعد",
"Share" => "شارك",
"Share link" => "شارك الرابط",
"Link" => "الرابط",
"Password protect" => "حماية كلمة السر",
"Password" => "كلمة المرور",
"Choose a password for the public link" => "اختر كلمة مرور للرابط العام",
"Allow editing" => "السماح بالتعديلات",
"Email link to person" => "ارسل الرابط بالبريد الى صديق",
"Send" => "أرسل",
"Set expiration date" => "تعيين تاريخ إنتهاء الصلاحية",
"Expiration" => "إنتهاء",
"Expiration date" => "تاريخ إنتهاء الصلاحية",
"Adding user..." => "إضافة مستخدم",
"group" => "مجموعة",
"remote" => "عن بعد",
"Resharing is not allowed" => "لا يسمح بعملية إعادة المشاركة",
"Shared in {item} with {user}" => "شورك في {item} مع {user}",
"Unshare" => "إلغاء المشاركة",
"notify by email" => "الإشعار عن طريق البريد",
"can share" => "يمكن المشاركة",
"can edit" => "يمكن التحرير",
"access control" => "ضبط الوصول",
"create" => "إنشاء",
"change" => "تغيير",
"delete" => "حذف",
"Password protected" => "محمي بكلمة السر",
"Error unsetting expiration date" => "حصل خطأ عند عملية إزالة تاريخ إنتهاء الصلاحية",
"Error setting expiration date" => "حصل خطأ عند عملية تعيين تاريخ إنتهاء الصلاحية",
"Sending ..." => "جاري الارسال ...",
"Email sent" => "تم ارسال البريد الالكتروني",
"Warning" => "تحذير",
"Edit" => "تعديل",
"Local" => "محلي",
"External" => "خارجي",
"Disabled" => "معطلة",
"Server URL" => "رابط السيرفر",
"New document" => "مستند جديد",
"Upload (max. %s)" => "الرفع ( حد اقصى. %s ) ",
"Upload" => "رفع",
"Save new documents to" => "حفظ المستندات الجديدة إلى",
"Wrong password. Please retry." => "كلمة مرور خاطئة. يرجى إعادة المحاولة",
"This link has been expired or is never existed. Please contact the person who shared it with you for details." => "هذا الرابط قد انتهى او لم ينشئ. يرجى الاتصال بالشخص المعني للمزيد من المعلومات.",
"Advanced feature-set" => "طقم الأدوات المتقدم",
"(Unstable)" => "(غير مستقر)"
);
$PLURAL_FORMS = "nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;";
